==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/SecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface SecurityContextFluent<A extends io.fabric8.kubernetes.api.model.SecurityContextFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getAllowPrivilegeEscalation();
  public A withAllowPrivilegeEscalation(java.lang.Boolean allowPrivilegeEscalation);
  public java.lang.Boolean hasAllowPrivilegeEscalation();
  
  /**
   * This method has been deprecated, please use method buildCapabilities instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Capabilities getCapabilities();
  public io.fabric8.kubernetes.api.model.Capabilities buildCapabilities();
  public A withCapabilities(io.fabric8.kubernetes.api.model.Capabilities capabilities);
  public java.lang.Boolean hasCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> withNewCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> withNewCapabilitiesLike(io.fabric8.kubernetes.api.model.Capabilities item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilitiesLike(io.fabric8.kubernetes.api.model.Capabilities item);
  public java.lang.Boolean getPrivileged();
  public A withPrivileged(java.lang.Boolean privileged);
  public java.lang.Boolean hasPrivileged();
  public java.lang.String getProcMount();
  public A withProcMount(java.lang.String procMount);
  public java.lang.Boolean hasProcMount();
  
  /**
   * Method is deprecated. use withProcMount instead.
   */
  @java.lang.Deprecated
  public A withNewProcMount(java.lang.String arg0);
  public java.lang.Boolean getReadOnlyRootFilesystem();
  public A withReadOnlyRootFilesystem(java.lang.Boolean readOnlyRootFilesystem);
  public java.lang.Boolean hasReadOnlyRootFilesystem();
  public java.lang.Long getRunAsGroup();
  public A withRunAsGroup(java.lang.Long runAsGroup);
  public java.lang.Boolean hasRunAsGroup();
  public java.lang.Boolean getRunAsNonRoot();
  public A withRunAsNonRoot(java.lang.Boolean runAsNonRoot);
  public java.lang.Boolean hasRunAsNonRoot();
  public java.lang.Long getRunAsUser();
  public A withRunAsUser(java.lang.Long runAsUser);
  public java.lang.Boolean hasRunAsUser();
  
  /**
   * This method has been deprecated, please use method buildSeLinuxOptions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SELinuxOptions getSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SELinuxOptions buildSeLinuxOptions();
  public A withSeLinuxOptions(io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions);
  public java.lang.Boolean hasSeLinuxOptions();
  public A withNewSeLinuxOptions(java.lang.String level,java.lang.String role,java.lang.String type,java.lang.String user);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(io.fabric8.kubernetes.api.model.SELinuxOptions item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(io.fabric8.kubernetes.api.model.SELinuxOptions item);
  
  /**
   * This method has been deprecated, please use method buildSeccompProfile instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SeccompProfile getSeccompProfile();
  public io.fabric8.kubernetes.api.model.SeccompProfile buildSeccompProfile();
  public A withSeccompProfile(io.fabric8.kubernetes.api.model.SeccompProfile seccompProfile);
  public java.lang.Boolean hasSeccompProfile();
  public A withNewSeccompProfile(java.lang.String localhostProfile,java.lang.String type);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfileLike(io.fabric8.kubernetes.api.model.SeccompProfile item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfileLike(io.fabric8.kubernetes.api.model.SeccompProfile item);
  
  /**
   * This method has been deprecated, please use method buildWindowsOptions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions getWindowsOptions();
  public io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions buildWindowsOptions();
  public A withWindowsOptions(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions windowsOptions);
  public java.lang.Boolean hasWindowsOptions();
  public A withNewWindowsOptions(java.lang.String gmsaCredentialSpec,java.lang.String gmsaCredentialSpecName,java.lang.Boolean hostProcess,java.lang.String runAsUserName);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions item);
  public interface CapabilitiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.CapabilitiesFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<N>>{
    public N and();
    public N endCapabilities();
    
  }
  public interface SeLinuxOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SELinuxOptionsFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<N>>{
    public N and();
    public N endSeLinuxOptions();
    
  }
  public interface SeccompProfileNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SeccompProfileFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<N>>{
    public N and();
    public N endSeccompProfile();
    
  }
  public interface WindowsOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<N>>{
    public N and();
    public N endWindowsOptions();
    
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/SecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface SecurityContextFluent<A extends io.fabric8.kubernetes.api.model.SecurityContextFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.Boolean getAllowPrivilegeEscalation();
  public A withAllowPrivilegeEscalation(java.lang.Boolean allowPrivilegeEscalation);
  public java.lang.Boolean hasAllowPrivilegeEscalation();
  
  /**
   * This method has been deprecated, please use method buildCapabilities instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.Capabilities getCapabilities();
  public io.fabric8.kubernetes.api.model.Capabilities buildCapabilities();
  public A withCapabilities(io.fabric8.kubernetes.api.model.Capabilities capabilities);
  public java.lang.Boolean hasCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> withNewCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> withNewCapabilitiesLike(io.fabric8.kubernetes.api.model.Capabilities item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilities();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<A> editOrNewCapabilitiesLike(io.fabric8.kubernetes.api.model.Capabilities item);
  public java.lang.Boolean getPrivileged();
  public A withPrivileged(java.lang.Boolean privileged);
  public java.lang.Boolean hasPrivileged();
  public java.lang.String getProcMount();
  public A withProcMount(java.lang.String procMount);
  public java.lang.Boolean hasProcMount();
  
  /**
   * Method is deprecated. use withProcMount instead.
   */
  @java.lang.Deprecated
  public A withNewProcMount(java.lang.String arg0);
  public java.lang.Boolean getReadOnlyRootFilesystem();
  public A withReadOnlyRootFilesystem(java.lang.Boolean readOnlyRootFilesystem);
  public java.lang.Boolean hasReadOnlyRootFilesystem();
  public java.lang.Long getRunAsGroup();
  public A withRunAsGroup(java.lang.Long runAsGroup);
  public java.lang.Boolean hasRunAsGroup();
  public java.lang.Boolean getRunAsNonRoot();
  public A withRunAsNonRoot(java.lang.Boolean runAsNonRoot);
  public java.lang.Boolean hasRunAsNonRoot();
  public java.lang.Long getRunAsUser();
  public A withRunAsUser(java.lang.Long runAsUser);
  public java.lang.Boolean hasRunAsUser();
  
  /**
   * This method has been deprecated, please use method buildSeLinuxOptions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SELinuxOptions getSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SELinuxOptions buildSeLinuxOptions();
  public A withSeLinuxOptions(io.fabric8.kubernetes.api.model.SELinuxOptions seLinuxOptions);
  public java.lang.Boolean hasSeLinuxOptions();
  public A withNewSeLinuxOptions(java.lang.String level,java.lang.String role,java.lang.String type,java.lang.String user);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(io.fabric8.kubernetes.api.model.SELinuxOptions item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(io.fabric8.kubernetes.api.model.SELinuxOptions item);
  
  /**
   * This method has been deprecated, please use method buildSeccompProfile instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.SeccompProfile getSeccompProfile();
  public io.fabric8.kubernetes.api.model.SeccompProfile buildSeccompProfile();
  public A withSeccompProfile(io.fabric8.kubernetes.api.model.SeccompProfile seccompProfile);
  public java.lang.Boolean hasSeccompProfile();
  public A withNewSeccompProfile(java.lang.String localhostProfile,java.lang.String type);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfileLike(io.fabric8.kubernetes.api.model.SeccompProfile item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfile();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfileLike(io.fabric8.kubernetes.api.model.SeccompProfile item);
  
  /**
   * This method has been deprecated, please use method buildWindowsOptions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions getWindowsOptions();
  public io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions buildWindowsOptions();
  public A withWindowsOptions(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions windowsOptions);
  public java.lang.Boolean hasWindowsOptions();
  public A withNewWindowsOptions(java.lang.String gmsaCredentialSpec,java.lang.String gmsaCredentialSpecName,java.lang.Boolean hostProcess,java.lang.String runAsUserName);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions item);
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
  public io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(io.fabric8.kubernetes.api.model.WindowsSecurityContextOptions item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface CapabilitiesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.CapabilitiesFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.CapabilitiesNested<N>>{
    public N and();
    public N endCapabilities();
    
  }
  public interface SeLinuxOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SELinuxOptionsFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.SeLinuxOptionsNested<N>>{
    public N and();
    public N endSeLinuxOptions();
    
  }
  public interface SeccompProfileNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.SeccompProfileFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.SeccompProfileNested<N>>{
    public N and();
    public N endSeccompProfile();
    
  }
  public interface WindowsOptionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.WindowsSecurityContextOptionsFluent<io.fabric8.kubernetes.api.model.SecurityContextFluent.WindowsOptionsNested<N>>{
    public N and();
    public N endWindowsOptions();
    
  }
  
}
